@@ -1,4 +1,3 @@
-# -*- encoding: utf-8 -*-
 # Copyright (c) 2016 b<>com
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -34,6 +33,7 @@ LOG = logging.getLogger(__name__)
 class IndexView(horizon.tables.DataTableView):
     table_class = tables.ActionsTable
     template_name = 'infra_optim/actions/index.html'
+    page_title = _("Actions")
 
     def get_context_data(self, **kwargs):
         context = super(IndexView, self).get_context_data(**kwargs)
