@@ -1,4 +1,3 @@
-# -*- encoding: utf-8 -*-
 # Copyright (c) 2016 b<>com
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -122,6 +121,9 @@ class AuditsTable(horizon.tables.DataTable):
     audit_type = horizon.tables.Column(
         'audit_type',
         verbose_name=_('Audit Type'))
+    auto_trigger = horizon.tables.Column(
+        'auto_trigger',
+        verbose_name=_('Auto Trigger'))
     status = horizon.tables.Column(
         'state',
         verbose_name=_('State'),
